@@ -23,7 +23,7 @@ def main():
     cur_dir = os.getcwd()
     mig_dir = os.path.join(cur_dir, 'migrator')
     if os.path.exists(mig_dir):
-        logger.info('directory migrator already present')
+        logger.info('directory migrator already present. please delete/rename and try again!')
         return
     os.mkdir(mig_dir)
     src_dir = os.path.dirname(__file__)
