@@ -159,13 +159,16 @@ class PackDb:
         self.buildout, self.name, self.options = buildout, name, options
         instance = options['instance']
         self.instance = buildout[instance]
-        self.db_name = options['db_name']
+        self.db_name = options.get('db_name', 'main')
+        self.old_db = options.get('old_db', None)
         self.path = os.path.join(buildout['buildout']['directory'], 'parts', self.name)
 
     def install(self):
-        """ copy file, create external method and run it """
+        """ pack database and remove old Data.fs if needed """
         br = utils.get_browser(self.instance)
         out = utils.pack_db(self.instance, self.db_name, br)
+        if self.old_db:
+            utils.remove_file(self.instance, self.old_db)
         if not os.path.exists(self.path): os.mkdir(self.path)
         fp = open('%s/out.txt' % self.path, "w")
         print >> fp, out
@@ -192,8 +195,9 @@ class ImportObject:
         for obj1 in self.obj:
             if self.replace:
                 utils.del_object(self.instance, obj1, br)
-            if not utils.import_one(self.instance, obj1, br):
-                logging.getLogger(self.name).error('Cannot import %s.', obj1)
+            rc = utils.import_one(self.instance, obj1, br)
+            if rc:
+                logging.getLogger(self.name).error('Cannot import %s: %s', obj1, rc)
 
         if not os.path.exists(self.path): os.mkdir(self.path)
         return self.path
@@ -227,3 +231,22 @@ class SubmitUrl:
         pass
 
 
+
+class PrepareContent:
+
+    def __init__(self, buildout, name, options):
+        self.name, self.options = name, options
+        self.top_folder = options['top_folder']
+        self.path = os.path.join(buildout['buildout']['directory'], 'parts', self.name)
+
+    def install(self):
+        """ copy file, create external method and run it """
+        rc = utils.prepare_content(self.top_folder)
+        if not os.path.exists(self.path): os.mkdir(self.path)
+        logging.getLogger(self.name).info(rc)
+        return self.path
+
+    def update(self):
+        pass
+
+
